MiniJSON
========
[![Documentation Status](https://readthedocs.org/projects/minijson/badge/?version=latest)](http://minijson.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/pyversions/minijson.svg)](https://pypi.python.org/pypi/minijson)
[![PyPI version](https://badge.fury.io/py/minijson.svg)](https://badge.fury.io/py/minijson)
[![PyPI](https://img.shields.io/pypi/implementation/minijson.svg)](https://pypi.python.org/pypi/minijson)

MiniJSON is a codec for a compact binary representation of a subset of JSON.

Usage
-----

Refer to the [documentation](http://minijson.readthedocs.io/en/latest/?badge=latest)
for use.

If there are no binary wheels precompiled for this platform, you will need to compile it yourself.

In order to do that you must have the following packages installed:

* snakehouse
* satella
* Cython
